@@ -88,20 +88,6 @@ nco_find_lat_lon
 
   } /* !idx */
   
-  /* Backup method, use "latitude" and "longitude", if they exist */
-  if((*lat_id == NC_MIN_INT) || (*lon_id == NC_MIN_INT)){
-    (void)fprintf(stdout,"%s: INFO %s auxiliary coordinate variables with standard_name attributes of \"latitude\" and \"longitude\" do not exist. Attempting to find latitude and longitude variables from pre-stored database instead...\n",nco_prg_nm_get(),fnc_nm);
-    if(*lon_id == NC_MIN_INT){
-      if((rcd=nco_inq_varid_flg(nc_id,"longitude",lon_id)) == NC_NOERR) var_nm_lon=strdup("longitude"); 
-      else if((rcd=nco_inq_varid_flg(nc_id,"lon",lon_id)) == NC_NOERR) var_nm_lon=strdup("lon"); 
-      else if((rcd=nco_inq_varid_flg(nc_id,"Longitude",lon_id)) == NC_NOERR) var_nm_lon=strdup("Longitude"); 
-    } /* !lon_id */
-    if(*lat_id == NC_MIN_INT){
-      if((rcd=nco_inq_varid_flg(nc_id,"latitude",lat_id)) == NC_NOERR) var_nm_lat=strdup("latitude"); 
-      else if((rcd=nco_inq_varid_flg(nc_id,"lat",lat_id)) == NC_NOERR) var_nm_lat=strdup("lat"); 
-      else if((rcd=nco_inq_varid_flg(nc_id,"Latitude",lat_id)) == NC_NOERR) var_nm_lat=strdup("Latitude"); 
-    } /* !lon_id */
-  } /* !crd_nbr */
 
   if((*lat_id == NC_MIN_INT) || (*lon_id == NC_MIN_INT)){
     if(nco_dbg_lvl_get() >= nco_dbg_std) (void)fprintf(stdout,"%s: %s unable to identify lat/lon auxiliary coordinate variables.\n",nco_prg_nm_get(),fnc_nm);
@@ -636,3 +622,73 @@ nco_find_lat_lon_trv
   return False;
 
 } /* end nco_find_lat_lon_trv() */
+
+nco_bool                             /* O [flg] True if all criteria met */  
+nco_check_nm_aux
+(const int nc_id,                    /* I [ID] netCDF file ID */
+ const trv_sct * const var_trv,      /* I [sct] Variable to search for "standard_name" attribute */
+ int *dmn_id,                        /* I/O [id] Dimension ID of "latitude" and "longitude" */
+ nc_type *crd_typ,                   /* I/O [enm] netCDF type of both "latitude" and "longitude" */
+ char units[])                       /* I/O [sng] Units of both "latitude" and "longitude" */
+{
+  /* Purpose: Check that variable var_trv fits the criteria for being an auxiliary coordinate  
+     Must be 1D and NOT a record var and NOT a standard coordinate variable
+     Also must have a "units" attribute   
+     If all critera met - then return some information about variable */
+
+  const char fnc_nm[]="nco_check_nm_aux()";
+
+  char var_nm[NC_MAX_NAME];
+
+  int rcd;
+  int grp_id;               /* [id] Group ID */
+  int var_id;               /* [id] Variable ID */
+  int var_dimid[NC_MAX_VAR_DIMS]; /* [enm] Dimension ID */
+  int var_att_nbr;          /* [nbr] Number of attributes */
+  int var_dmn_nbr;          /* [nbr] Number of dimensions */
+
+  long att_lng; 
+
+  nc_type var_typ;          /* [enm] variable type */
+
+  assert(var_trv->nco_typ == nco_obj_typ_var);
+
+  if(False ||
+     //     var_trv->is_1D_crd || /* 20180807: Not yet defined */
+     //     var_trv->is_1D_rec_crd || /* 20180807: Not yet defined */
+     var_trv->is_crd_var)
+    return False;
+  
+  /* Obtain group ID */
+  (void)nco_inq_grp_full_ncid(nc_id,var_trv->grp_nm_fll,&grp_id);
+
+  /* Obtain variable ID */
+  (void)nco_inq_varid(grp_id,var_trv->nm,&var_id);
+
+  /* Obtain variable meta-data  */
+  (void)nco_inq_var(grp_id,var_id,var_nm,&var_typ,&var_dmn_nbr,var_dimid,&var_att_nbr);
+
+  assert(var_att_nbr == var_trv->nbr_att);
+
+  /* Assume same units (degrees or radians) for both lat and lon */
+  rcd=nco_inq_attlen_flg(grp_id,var_id,"units",&att_lng);
+  
+  if(rcd != NC_NOERR){
+    if(nco_dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stdout,"%s: %s reports CF convention requires \"%s\" to have units attribute\n",nco_prg_nm_get(),fnc_nm,var_nm);
+    return False;
+  } /* endif */
+  
+  NCO_GET_ATT_CHAR(grp_id,var_id,"units",units);
+  units[att_lng]='\0';
+
+  /* Auxiliary coordinates MUST be 1D */
+  if(var_dmn_nbr != 1) return False;
+  
+  /* Copy values to export */
+  *crd_typ=var_typ;
+  *dmn_id=var_dimid[0];
+
+  return True;
+
+} /* !nco_check_nm_aux() */
+
